@@ -315,7 +315,7 @@ class OptionIVDiffStrategy(Strategy):
             return processed_tickers
         return ticker_list
     
-    def processStrategy(self, ticker, nextExpiryCount = 1):
+    def processStrategy(self, ticker, nextExpiryCount = 1, threshold = 0.01):
         
         df = self.helper.formatedOptionChain(ticker, False)
         nearestExpiry = list(set(df.expiryDate.values))
@@ -344,10 +344,10 @@ class OptionIVDiffStrategy(Strategy):
         strike_high_call_price = df[df['strikePrice'].isin([strike_high])].call_price.values[0]
         strike_high_call_nxt_price = df[df['strikePrice'].isin([strike_high_nxt])].call_price.values[0]
         lot_size = self.lot_sizes.get(ticker, 1)
-        strike_low_max_profit = (strike_low_put_price - strike_low_put_nxt_price)*lot_size
-        strike_low_max_loss = (strike_low_nxt - strike_low)*lot_size + strike_low_max_profit
-        strike_high_max_profit = (strike_high_call_price - strike_high_call_nxt_price)*lot_size
-        strike_high_max_loss = (strike_high_nxt - strike_high)*lot_size + strike_high_max_profit
+        strike_low_max_profit = round((strike_low_put_price - strike_low_put_nxt_price)*lot_size,2)
+        strike_low_max_loss = round((strike_low_nxt - strike_low)*lot_size + strike_low_max_profit,2)
+        strike_high_max_profit = round((strike_high_call_price - strike_high_call_nxt_price)*lot_size,2)
+        strike_high_max_loss = round((strike_high - strike_high_nxt)*lot_size + strike_high_max_profit,2)
         
         data = {
             'ticker' : ticker,
@@ -373,11 +373,12 @@ class OptionIVDiffStrategy(Strategy):
             'strike_high_max_profit' : strike_high_max_profit,
             'strike_high_max_loss' : strike_high_max_loss
             }
-        data['strategy_action'], data['strategy_max_profit'], data['strategy_max_loss'] = self._getAction(data)
+        data['strategy_action'], data['strategy_max_profit'], data['strategy_max_loss'] = self._getAction(data, threshold)
+        data['risk_reward'] = round(abs(data['strategy_max_profit']/data['strategy_max_loss']),2) if data['strategy_max_loss'] != 0 else 0
         data['strategy_summary'] = self._strategySummary(data)
         return data
     
-    def screener(self,nextExpiryCount = 1):
+    def screener(self,nextExpiryCount = 1, threshold = 0.01):
         
         result = []
         ticker_list = self.getTickerList()
@@ -391,7 +392,7 @@ class OptionIVDiffStrategy(Strategy):
                 sample_tickers = pending_tickers
             for ticker in sample_tickers:
                 try:
-                    data = self.processStrategy(ticker, nextExpiryCount)
+                    data = self.processStrategy(ticker, nextExpiryCount, threshold)
                     result.append(data)
                 except:
                     pass
@@ -422,10 +423,10 @@ class OptionIVDiffStrategy(Strategy):
         filtered_strikes = strikes[:count]
         return filtered_strikes
     
-    def _getAction(self, x, threshold = 10):
+    def _getAction(self, x, threshold = 0.01):
         
         action = ('', 0, 0) # (action, max_profit, max_loss)
-        if abs(x['iv_diff']) >= threshold:
+        if abs(x['iv_diff']) > threshold:
             if x['iv_diff'] > 0:
                 action = ('Sell PUT', x['strike_low_max_profit'], x['strike_low_max_loss'])
             else:
@@ -440,26 +441,19 @@ class OptionIVDiffStrategy(Strategy):
             message += 'Buy PUT@' + str(x['strike_low_nxt']) + ' for ' + str(x['strike_low_pe_nxt_price']) +'\n'
             message += '<b>Max Profit:</b> ' + str(x['strategy_max_profit']) + '\n'
             message += '<b>Max Loss:</b> ' + str(x['strategy_max_loss']) + '\n'
+            message += '<b>RR:</b> ' + str(x['risk_reward']) + '\n'
         elif x['strategy_action'] == 'Sell CALL':
             message += '<b>' + x['ticker'] + '</b>\n\n'
             message += '<b>Trades:</b>\n' + 'Sell CALL@' + str(x['strike_high']) + ' for ' + str(x['strike_high_ce_price']) +'\n'
             message += 'Buy CALL@' + str(x['strike_high_nxt']) + ' for ' + str(x['strike_high_ce_nxt_price']) +'\n'
             message += '<b>Max Profit:</b> ' + str(x['strategy_max_profit']) + '\n'
             message += '<b>Max Loss:</b> ' + str(x['strategy_max_loss']) + '\n'
+            message += '<b>RR:</b> ' + str(x['risk_reward']) + '\n'
         else:
             pass
         
         return message
     
-        if abs(x['iv_diff']) >= threshold:
-            if x['iv_diff'] > 0:
-                action = 'Sell ' + x['ticker'] + ' PUT@' + str(x['strike_low']) + ' for ' + str(x['strike_low_pe_price'])
-                action +=  ' and Buy ' + x['ticker'] + ' PUT@' + str(x['strike_low_nxt']) + ' for ' + str(x['strike_low_pe_nxt_price'])
-            else:
-                action = 'Sell ' + x['ticker'] + ' CALL@' + str(x['strike_high']) + ' for ' + str(x['strike_high_ce_price'])
-                action +=  ' and Buy ' + x['ticker'] + ' CALL@' + str(x['strike_high_nxt']) + ' for ' + str(x['strike_high_ce_nxt_price'])
-        return action
-    
     
 # Screener Strategies       
 class ScreenerData:
